@@ -1,3 +1,10 @@
+/*
+  mainwindow.h
+  Project: masudoku
+  Platform: Fremantle (maemo5)
+  Author: Petri Kultanen pete@petnetti.net
+  Last Edit: 15.2.2010
+*/
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
@@ -15,7 +22,7 @@ class MainWindow : public QMainWindow
 {
     Q_OBJECT
 
-public slots:
+    public slots:
     void changeNumber(int aX,int aY);
     //void numberChanged(int aNum);
     void showError(QString aString);
@@ -26,7 +33,7 @@ public slots:
     void repaintElements();
     void toggleNumberTypes();
     void checkTable();
-void aboutt();
+    void aboutt();
 public:
     MainWindow(QWidget *parent = 0);
     ~MainWindow();
